# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Union
from . import utilities, tables


class VmStoragePolicy(pulumi.CustomResource):
    description: pulumi.Output[str]
    """
    Description of the storage policy.
    """
    name: pulumi.Output[str]
    """
    The name of the storage policy.
    """
    tag_rules: pulumi.Output[list]
    """
    List of tag rules. The tag category and tags to be associated to this storage policy.

      * `includeDatastoresWithTags` (`bool`) - Whether to include datastores with the given tags or exclude. Default 
        value is true i.e. include datastores with the given tags.
      * `tagCategory` (`str`) - Name of the tag category.
      * `tags` (`list`) - List of Name of tags to select from the given category.
    """
    def __init__(__self__, resource_name, opts=None, description=None, name=None, tag_rules=None, __props__=None, __name__=None, __opts__=None):
        """
        The `VmStoragePolicy` resource can be used to create and manage storage
        policies. Using this storage policy, tag based placement rules can be created to
        place a VM on a particular tagged datastore.

        ## Example Usage

        This example creates a storage policy with tag_rule having cat1 as tag_category and
        tag1, tag2 as the tags. While creating a VM, this policy can be referenced to place
        the VM in any of the compatible datastore tagged with these tags.

        ```python
        import pulumi
        import pulumi_vsphere as vsphere

        dc = vsphere.get_datacenter(name="DC")
        tag_category = vsphere.get_tag_category(name="cat1")
        tag1 = vsphere.get_tag(name="tag1",
            category_id=tag_category.id)
        tag2 = vsphere.get_tag(name="tag2",
            category_id=tag_category.id)
        policy_tag_based_placement = vsphere.VmStoragePolicy("policyTagBasedPlacement",
            description="description",
            tag_rules=[{
                "tagCategory": tag_category.name,
                "tags": [
                    tag1.name,
                    tag2.name,
                ],
                "includeDatastoresWithTags": True,
            }])
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] description: Description of the storage policy.
        :param pulumi.Input[str] name: The name of the storage policy.
        :param pulumi.Input[list] tag_rules: List of tag rules. The tag category and tags to be associated to this storage policy.

        The **tag_rules** object supports the following:

          * `includeDatastoresWithTags` (`pulumi.Input[bool]`) - Whether to include datastores with the given tags or exclude. Default 
            value is true i.e. include datastores with the given tags.
          * `tagCategory` (`pulumi.Input[str]`) - Name of the tag category.
          * `tags` (`pulumi.Input[list]`) - List of Name of tags to select from the given category.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['description'] = description
            __props__['name'] = name
            if tag_rules is None:
                raise TypeError("Missing required property 'tag_rules'")
            __props__['tag_rules'] = tag_rules
        super(VmStoragePolicy, __self__).__init__(
            'vsphere:index/vmStoragePolicy:VmStoragePolicy',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, description=None, name=None, tag_rules=None):
        """
        Get an existing VmStoragePolicy resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] description: Description of the storage policy.
        :param pulumi.Input[str] name: The name of the storage policy.
        :param pulumi.Input[list] tag_rules: List of tag rules. The tag category and tags to be associated to this storage policy.

        The **tag_rules** object supports the following:

          * `includeDatastoresWithTags` (`pulumi.Input[bool]`) - Whether to include datastores with the given tags or exclude. Default 
            value is true i.e. include datastores with the given tags.
          * `tagCategory` (`pulumi.Input[str]`) - Name of the tag category.
          * `tags` (`pulumi.Input[list]`) - List of Name of tags to select from the given category.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["description"] = description
        __props__["name"] = name
        __props__["tag_rules"] = tag_rules
        return VmStoragePolicy(resource_name, opts=opts, __props__=__props__)

    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop
